ExpandMsgXofError

Enum ExpandMsgXofError 

pub enum ExpandMsgXofError {
    EmptyDst,
    DstSecurityLevel,
}
Error type for ExpandMsgXof.

Variants



EmptyDst

The domain separation tag is invalid because it is empty.



DstSecurityLevel

The target security level (K) must not be greater then 127 if the domain separation tag is longer than 255.